"""Class to represent the camera device using open cv."""

import cv2


class Camera:
    """Manipulate the camera object. Use my current camera settings by default.

    :param port: Port index of the camera. Default to 1 since 0 is internal.
    :param width: Frame width setting in camera. Default to 1280.
    :param height: Frame height setting in camera. Default to 800.
    :param fps: Frame per second setting in camera. Default to 120.
    """

    def __init__(self, port=1, width=1280, height=800, fps=120):
        """Constructor method."""
        self.cap = cv2.VideoCapture(port)

        if not self.cap.isOpened():
            raise ValueError(f"Could not open camera at port={port}")

        self.cap.set(cv2.CAP_PROP_FRAME_WIDTH, width)
        self.cap.set(cv2.CAP_PROP_FRAME_HEIGHT, height)
        self.cap.set(cv2.CAP_PROP_FPS, fps)

    def width(self):
        """Return the width of the frame in camera.

            :returns: Width in pixels.
            :rtype: int
        """
        return int(self.cap.get(cv2.CAP_PROP_FRAME_WIDTH))

    def height(self):
        """ Returns the height of the frame in camera.

            :returns: Height in pixels.
            :rtype: int
        """
        return int(self.cap.get(cv2.CAP_PROP_FRAME_HEIGHT))

    def fps(self):
        """Return the frames per second of camera."""
        return int(self.cap.get(cv2.CAP_PROP_FPS))

    def read_frame(self):
        """Read a frame from the camera."""
        ret, frame = self.cap.read()
        if not ret:
            raise IOError("Camera could not capture a frame")
        return frame

    def read_gray_frame(self):
        """Return the gray frame from the camera."""
        frame = self.read_frame()
        gray = cv2.cvtColor(frame, cv2.COLOR_BGR2GRAY)
        return gray

    def take_video(self, fname, time_secs=4):
        """Capture video from camera to a file.

            :fname: Output filename with mp4 extension
            :time_secs: Time in seconds for recording.

            :returns: None
        """
        writer = cv2.VideoWriter(
            fname,
            cv2.VideoWriter_fourcc(*"mp4v"),
            self.fps(),
            (self.width(), self.height()),
        )

        num_frames = time_secs * self.fps()

        for _ in range(num_frames):
            frame = self.read_frame()
            writer.write(frame)

        writer.release()

    def take_picture(self, fname):
        """ Save a frame from the camera to a file.

            :fname: Output filename with .png extension.
            :returns: None
        """
        frame = self.read_frame()
        cv2.imwrite(fname, frame)

    def __del__(self):
        self.cap.release()



"""
Splits the video into frames stored as png files.
"""

import argparse
import sys


def parse_args(args):
    """ Command line parser. """
    parser = argparse.ArgumentParser(description="Capture video from camera to mp4 file.")
    parser.add_argument('--index', '-i', default=0, type=int, help="Camera index on this mc.")
    parser.add_argument('--time', '-t', default=4, type=int, help='Seconds to capture the video')
    parser.add_argument('outfile', type=str, help="Output mp4 file to store the video.")
    opt = parser.parse_args(args)

    if len(args) == 1:
        parser.print_help(sys.stderr)
        sys.exit(-1)

    return opt


def main():
    """ Main program. """
    opt = parse_args(sys.argv)


if __name__ == "__main__":
    main()


"""
Captures the video from the camera to a file.
"""

import argparse
import sys


def parse_args(args):
	""" Command line parser. """
	parser = argparse.ArgumentParser(description="Capture video from camera to mp4 file.")
	parser.add_argument('--index', '-i', default=0, type=int, help="Camera index on this mc.")
	parser.add_argument('--time', '-t', default=4, type=int, help='Seconds to capture the video')
	parser.add_argument('outfile', type=str, help="Output mp4 file to store the video.")
	opt = parser.parse_args(args)

	if len(args) == 1:
		parser.print_help(sys.stderr)
		sys.exit(-1)
		
	return opt

def main():
	""" Main program. """
	opt = parse_args(sys.argv)

if __name__ == "__main__":
	main()


from spvideoutils.video_capture import main
import pytest

def test_video_capture_default():
	"""By default it should print help and exit with -1."""
	with pytest.raises(SystemExit) as pytest_wrapped_e:
		main()
	assert pytest_wrapped_e.type == SystemExit
	assert pytest_wrapped_e.value.code == -1




from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="spvideoutils",
    version="0.0.1",
    description="Scripts for saving and splitting video files for other projects",
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 3 - Alpha"
    ],
    url="https://github.com/sanjeevs/spvideoutils",
    author="Sanjeev Singh",
    author_email="snjvsingh123@gmail.com",
    entry_points={
        'console_scripts' : [
            'video_capture=spvideoutils.video_capture:main',
            'video_split=spvideoutils.video_split:main'
        ]
    },
    install_requires = ['opencv-python'],
    packages = ['spvideoutils'],
    extras_require = {
        "dev": [
            "pytest >= 3.7",
            "check-manifest",
            "twine",
        ],
    }
)